@@ -65,7 +65,7 @@ delimited_index_connection::delimited_index_connection(
   idx_[0].reserve(128);
 
   size_t sz = R_ReadConnection(con, buf[i].data(), chunk_size - 1);
-  buf[i][sz] = '\0';
+  buf[i].resize(sz + 1);
 
   if (sz == 0) {
     if (should_close) {
@@ -77,7 +77,6 @@ delimited_index_connection::delimited_index_connection(
   // Parse header
   size_t start = find_first_line(buf[i], skip_, comment_);
 
-  std::string delim_;
   if (delim == nullptr) {
     delim_ = std::string(1, guess_delim(buf[i], start, 5, sz));
   } else {
@@ -88,6 +87,8 @@ delimited_index_connection::delimited_index_connection(
 
   size_t first_nl = find_next_newline(buf[i], start);
 
+  bool single_line = first_nl == buf[i].size() - 1;
+
   if (sz > 1 && buf[i][first_nl] != '\n') {
     // This first newline must not have fit in the buffer, throw error
     // suggesting a larger buffer size.
@@ -193,6 +194,7 @@ delimited_index_connection::delimited_index_connection(
     i = (i + 1) % 2;
     sz = R_ReadConnection(con, buf[i].data(), chunk_size - 1);
     if (sz > 0) {
+      buf[i].resize(sz + 1);
       buf[i][sz] = '\0';
     }
 
@@ -226,16 +228,16 @@ delimited_index_connection::delimited_index_connection(
   size_t file_size = mmap_.size();
 
   if (mmap_[file_size - 1] != '\n') {
-    if (columns_ == 0) {
-      ++columns_;
+    if (columns_ == 0 || single_line) {
       idx_[0].push_back(file_size);
+      ++columns_;
     } else {
       idx_[1].push_back(file_size);
     }
   }
 
   size_t total_size = std::accumulate(
-      idx_.begin(), idx_.end(), 0, [](size_t sum, const idx_t& v) {
+      idx_.begin(), idx_.end(), std::size_t{0}, [](size_t sum, const idx_t& v) {
         sum += v.size() > 0 ? v.size() - 1 : 0;
         return sum;
       });
