@@ -18,6 +18,16 @@ inline int get_pb_width(const std::string& format) {
   return Rcpp::as<int>(fun(format));
 }
 
+inline void rethrow_rcpp_eval_error(const Rcpp::eval_error& e) {
+  std::string msg = e.what();
+  // Remove "Evaluation error: "
+  msg.erase(0, 18);
+  // Remove trailing period
+  msg.erase(msg.length() - 1);
+
+  throw Rcpp::exception(msg.c_str(), false);
+}
+
 template <typename T>
 static char guess_delim(
     const T& source, size_t start, size_t guess_max = 5, size_t end = 0) {
@@ -28,7 +38,7 @@ static char guess_delim(
   }
 
   auto nl = find_next_newline(source, start);
-  while (nl > start && nl < end && guess_max > 0) {
+  while (nl > start && nl <= end && guess_max > 0) {
     auto str = std::string(source.data() + start, nl - start);
     lines.push_back(str);
     start = nl + 1;
@@ -37,7 +47,14 @@ static char guess_delim(
   }
 
   Rcpp::Function fun = Rcpp::Environment::namespace_env("vroom")["guess_delim"];
-  return Rcpp::as<char>(fun(lines));
+
+  char delim;
+  try {
+    delim = Rcpp::as<char>(fun(lines));
+  } catch (const Rcpp::eval_error& e) {
+    rethrow_rcpp_eval_error(e);
+  }
+  return delim;
 }
 
 } // namespace vroom
